pub struct NonAnyI128<const NICHE: i128>(/* private fields */);Expand description
An integer that is known not to equal NICHE.
This enables some memory layout optimization.
For example, Option<NonAnyI128<0>> is the same size as i128:
assert_eq!(core::mem::size_of::<Option<nonany::NonAnyI128<0>>>(), core::mem::size_of::<i128>());Implementations
Sourceimpl<const NICHE: i128> NonAnyI128<NICHE>
impl<const NICHE: i128> NonAnyI128<NICHE>
Sourcepub const fn new(value: i128) -> Option<Self>
pub const fn new(value: i128) -> Option<Self>
Creates a non-any if the given value is not NICHE.
Sourcepub const unsafe fn new_unchecked(value: i128) -> Self
pub const unsafe fn new_unchecked(value: i128) -> Self
Creates a non-any without checking whether the value is NICHE.
This results in undefined behaviour if the value is NICHE.
Safety
The value must not be NICHE.
pub const fn abs(self) -> Option<Self>
pub const fn checked_abs(self) -> Result<Self, CheckedError>
pub const fn is_positive(self) -> bool
pub const fn is_negative(self) -> bool