NonAnyI16

Struct NonAnyI16 

pub struct NonAnyI16<const NICHE: i16>(/* private fields */);
An integer that is known not to equal NICHE.

This enables some memory layout optimization. For example, Option<NonAnyI16<0>> is the same size as i16:

assert_eq!(core::mem::size_of::<Option<nonany::NonAnyI16<0>>>(), core::mem::size_of::<i16>());

Implementations

Source

impl<const NICHE: i16> NonAnyI16<NICHE>

pub const NICHE: i16 = NICHE

The niche value of this integer type.

pub const BITS: u32 = i16::BITS

The size of this integer type in bits.

pub const fn new(value: i16) -> Option<Self>

Creates a non-any if the given value is not NICHE.

pub const unsafe fn new_unchecked(value: i16) -> Self

Creates a non-any without checking whether the value is NICHE. This results in undefined behaviour if the value is NICHE.

Safety

The value must not be NICHE.

pub const fn get(self) -> i16

Returns the contained value as a primitive type.

pub const fn abs(self) -> Option<Self>

pub const fn checked_abs(self) -> Result<Self, CheckedError>

pub const fn is_positive(self) -> bool

pub const fn is_negative(self) -> bool