pub struct NonAnyU128<const NICHE: u128>(/* private fields */);Expand description
An integer that is known not to equal NICHE.
This enables some memory layout optimization.
For example, Option<NonAnyU128<0>> is the same size as u128:
assert_eq!(core::mem::size_of::<Option<nonany::NonAnyU128<0>>>(), core::mem::size_of::<u128>());Implementations
Sourceimpl<const NICHE: u128> NonAnyU128<NICHE>
impl<const NICHE: u128> NonAnyU128<NICHE>
Sourcepub const fn new(value: u128) -> Option<Self>
pub const fn new(value: u128) -> Option<Self>
Creates a non-any if the given value is not NICHE.
Sourcepub const unsafe fn new_unchecked(value: u128) -> Self
pub const unsafe fn new_unchecked(value: u128) -> Self
Creates a non-any without checking whether the value is NICHE.
This results in undefined behaviour if the value is NICHE.
Safety
The value must not be NICHE.