pub struct NonAnyU32<const NICHE: u32>(/* private fields */);Expand description
An integer that is known not to equal NICHE.
This enables some memory layout optimization.
For example, Option<NonAnyU32<0>> is the same size as u32:
assert_eq!(core::mem::size_of::<Option<nonany::NonAnyU32<0>>>(), core::mem::size_of::<u32>());Implementations
Sourceimpl<const NICHE: u32> NonAnyU32<NICHE>
impl<const NICHE: u32> NonAnyU32<NICHE>
Sourcepub const fn new(value: u32) -> Option<Self>
pub const fn new(value: u32) -> Option<Self>
Creates a non-any if the given value is not NICHE.
Sourcepub const unsafe fn new_unchecked(value: u32) -> Self
pub const unsafe fn new_unchecked(value: u32) -> Self
Creates a non-any without checking whether the value is NICHE.
This results in undefined behaviour if the value is NICHE.
Safety
The value must not be NICHE.