pub type NonMaxUsize = NonAnyUsize<{ usize::MAX }>;Expand description
An integer that is known not to equal usize::MAX.
Aliased Type
pub struct NonMaxUsize(/* private fields */);pub type NonMaxUsize = NonAnyUsize<{ usize::MAX }>;An integer that is known not to equal usize::MAX.
pub struct NonMaxUsize(/* private fields */);