pub type NonZeroIsize = NonAnyIsize<0>;Expand description
An integer that is known not to equal zero.
Aliased Type
pub struct NonZeroIsize(/* private fields */);pub type NonZeroIsize = NonAnyIsize<0>;An integer that is known not to equal zero.
pub struct NonZeroIsize(/* private fields */);