pub type NonZeroU128 = NonAnyU128<0>;Expand description
An integer that is known not to equal zero.
Aliased Type
pub struct NonZeroU128(/* private fields */);pub type NonZeroU128 = NonAnyU128<0>;An integer that is known not to equal zero.
pub struct NonZeroU128(/* private fields */);