pub type NonZeroUsize = NonAnyUsize<0>;Expand description
An integer that is known not to equal zero.
Aliased Type
pub struct NonZeroUsize(/* private fields */);pub type NonZeroUsize = NonAnyUsize<0>;An integer that is known not to equal zero.
pub struct NonZeroUsize(/* private fields */);