pub struct NonAnyI16<const NICHE: i16>(/* private fields */);Expand description
An integer that is known not to equal NICHE.
This enables some memory layout optimization.
For example, Option<NonAnyI16<0>> is the same size as i16:
assert_eq!(core::mem::size_of::<Option<nonany::NonAnyI16<0>>>(), core::mem::size_of::<i16>());Implementations
Sourceimpl<const NICHE: i16> NonAnyI16<NICHE>
impl<const NICHE: i16> NonAnyI16<NICHE>
Sourcepub const fn new(value: i16) -> Option<Self>
pub const fn new(value: i16) -> Option<Self>
Creates a non-any if the given value is not NICHE.
Sourcepub const unsafe fn new_unchecked(value: i16) -> Self
pub const unsafe fn new_unchecked(value: i16) -> Self
Creates a non-any without checking whether the value is NICHE.
This results in undefined behaviour if the value is NICHE.
Safety
The value must not be NICHE.
pub const fn abs(self) -> Option<Self>
pub const fn checked_abs(self) -> Result<Self, CheckedError>
pub const fn is_positive(self) -> bool
pub const fn is_negative(self) -> bool